import { ComponentInstance, HTMLStencilElement } from "@stencil/core/dist/declarations";
declare type ClickOutsideDecorator = (target: ComponentInstance, propertyKey: string) => void;
/**
 * Call this function as soon as the click outside of annotated method's host is done.
 * @example
```
@ClickOutside()
callback() {
  // this will run when click outside of element (host component) is done.
}
```
 */
export declare function ClickOutside(): ClickOutsideDecorator;
/**
 * Register callback function for HTMLElement to be executed when user clicks outside of element.
 * @example
```
<span
    ref={spanEl => registerClickOutside(this, spanEl, () => this.test())}>
      Hello, World!
</span>;
```
 */
export declare function registerClickOutside(component: ComponentInstance, element: HTMLClickOutsideElement, callback: () => void): void;
export interface HTMLClickOutsideElement extends HTMLStencilElement {
    clickOutsideRegistered?: boolean;
}
export {};
